raidutil

package
v0.0.0-...-3c2c9c2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 7, 2018 License: BSD-3-Clause Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateRaidArray

func CreateRaidArray(driveNames []string, volName string, raidLevel int, dryRun bool) string

CreateRaidArray runs the appropriate mdadm command for the given list of EbsVol that should be raided together. It takes dryRun as a boolean, where it tells you which mdadm it would have run

func PersistMdadm

func PersistMdadm() error

PersistMdadm dumps the current mdadm config to /etc/mdadm.conf

Types

This section is empty.

Jump to