Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateRaidArray ¶
CreateRaidArray runs the appropriate mdadm command for the given list of EbsVol that should be raided together. It takes dryRun as a boolean, where it tells you which mdadm it would have run
func PersistMdadm ¶
func PersistMdadm() error
PersistMdadm dumps the current mdadm config to /etc/mdadm.conf
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.